@@ -107,11 +107,11 @@ class FSMViewSetMixin(metaclass=FSMViewSetMixinMetaclass):
 
         if errors is None or len(errors.keys()) == 0:
             obj.fsm_context = {"current_user": request.user}
-            getattr(obj, action)()
+            getattr(obj, action)(by=request.user)
             obj.save()
 
             serializer = serializer_class(instance=obj, context=serializer_context)
-            return Response(serializer.data)
+            return Response({'instance': serializer.data})
 
         return Response(errors, status=status.HTTP_412_PRECONDITION_FAILED)
 
