@@ -10,8 +10,9 @@ from rest_fuzzysearch.search import RankedFuzzySearchFilter
 class SearchFieldsBridgerViewSetConfig(BridgerViewSetConfig):
 
     def get_metadata(self) -> str:
-        if SearchFilter in getattr(self.view, "filter_backends", []) or RankedFuzzySearchFilter in getattr(self.view, "filter_backends", []):
-            return self.view.search_fields
+        for backend in getattr(self.view, "filter_backends", []):
+            if isinstance(backend(), SearchFilter):
+                return self.view.search_fields
 
     @classmethod
     def get_metadata_key(cls):
